summaryrefslogtreecommitdiffstats
path: root/src/ui/dialog/polar-arrange-tab.cpp
diff options
context:
space:
mode:
authorThomas Holder <thomas@thomas-holder.de>2018-09-23 16:08:52 +0000
committerThomas Holder <thomas@thomas-holder.de>2018-09-23 16:08:52 +0000
commit78c3478e08ea6c33fbf265d8f22b02fa99660d8a (patch)
treea14d571ad2dbfdf5a3f08d03c0d215e0785d1cb8 /src/ui/dialog/polar-arrange-tab.cpp
parentInkscapestream: Incredible speed up for writing of strings (diff)
downloadinkscape-78c3478e08ea6c33fbf265d8f22b02fa99660d8a.tar.gz
inkscape-78c3478e08ea6c33fbf265d8f22b02fa99660d8a.zip
fix "Arrange" dialog with inverted y-axis
Diffstat (limited to 'src/ui/dialog/polar-arrange-tab.cpp')
-rw-r--r--src/ui/dialog/polar-arrange-tab.cpp10
1 files changed, 3 insertions, 7 deletions
diff --git a/src/ui/dialog/polar-arrange-tab.cpp b/src/ui/dialog/polar-arrange-tab.cpp
index 49b5a5790..a44218f07 100644
--- a/src/ui/dialog/polar-arrange-tab.cpp
+++ b/src/ui/dialog/polar-arrange-tab.cpp
@@ -184,11 +184,9 @@ static Geom::Point calcPoint(float cx, float cy, float rx, float ry, float angle
}
/**
* Returns the selected anchor point in document coordinates. If anchor
* is 0 to 8, then a bounding box point has been chosen. If it is 9 however
* the rotational center is chosen.
- * @todo still using a hack to get the real coordinate space (subtracting document height
- * and inverting axes)
*/
static Geom::Point getAnchorPoint(int anchor, SPItem *item)
{
@@ -237,11 +235,9 @@ static Geom::Point getAnchorPoint(int anchor, SPItem *item)
// If using center
if(anchor == 9)
source = item->getCenter();
- else
+ else if (SP_ACTIVE_DESKTOP)
{
- // FIXME:
- source[1] -= item->document->getHeight().value("px");
- source[1] *= -1;
+ source *= SP_ACTIVE_DESKTOP->doc2dt();
}
return source;
@@ -184,11 +184,9 @@ static Geom::Point calcPoint(float cx, float cy, float rx, float ry, float angle
}
/**
- * Returns the selected anchor point in document coordinates. If anchor
+ * Returns the selected anchor point in desktop coordinates. If anchor
* is 0 to 8, then a bounding box point has been chosen. If it is 9 however
* the rotational center is chosen.